Plugin: JS9Imarith

### JS9 Image Arithmetic

The Image Arithmetic plugin performs basic arithmetic operations (addition, subtraction, multiplication, division, minimum, maximum) between the currently displayed image and either another image or a constant real value.

To start, choose an arithmetic operation from the first menu. Next use the second menu to choose either a real value or another image as the second operand. In the former case, the constant value you enter into the text box will be applied to each pixel in the image. In the latter case, the operation is performed between the corresponding pixels in the two images.

Click the Run button to perform the arithmetic operation. A new raw data layer called "imarith" will be created containing the results of the operation. Successive runs are cumulative, so that you can build up a more complex operation from simple ones.

Click the Reset button to delete the "imarith" raw data layer, which will allow you to start afresh.

Note that the two images must have the same dimensions. We might be able to remove this restriction in the future, although it is unclear how one lines up images of different dimensions.